package io.zipcoder.crudapp;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import static org.mockito.Matchers.any;
import static org.mockito.Mockito.when;

public class PersonControllerTest {

    @Mock
    private PersonController controller;

    @Before
    public void setUp() throws Exception {

        MockitoAnnotations.initMocks(this);
    }

    @Test
    public void createPersonTest(){
        when(controller.createPerson(any(Person.class))).thenReturn(new ResponseEntity<>( HttpStatus.CREATED));

        Person p = new Person();
        ResponseEntity<Person> actual = controller.createPerson(p);
        ResponseEntity<Person> expected = new ResponseEntity<>(HttpStatus.CREATED);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void getPersonTest(){
        when(controller.getPerson(1)).thenReturn(new ResponseEntity<>( HttpStatus.OK));

        Person p = new Person();
        p.setId(1L);
        ResponseEntity<Person> actual = controller.getPerson(1);
        ResponseEntity<Person> expected = new ResponseEntity<>(HttpStatus.OK);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void updatePersonTest(){
        when(controller.updatePerson(any(Person.class))).thenReturn(new ResponseEntity<>( HttpStatus.OK));

        Person p = new Person();
        p.setId(1L);
        ResponseEntity<Person> actual = controller.updatePerson(any(Person.class));
        ResponseEntity<Person> expected = new ResponseEntity<>(HttpStatus.OK);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void deletePerson(){
        when(controller.deletePerson(1)).thenReturn(new ResponseEntity<>( HttpStatus.NO_CONTENT));

        ResponseEntity<Person> actual = controller.deletePerson(1);
        ResponseEntity<Person> expected = new ResponseEntity<>( HttpStatus.NO_CONTENT);

        Assert.assertEquals(expected, actual);
    }
}
